//#region imports
import { CommonModule } from "@angular/common";
import { Component, OnInit } from "@angular/core";
import { JobService } from "../../data-access/services/JobService.service";
import { NzTableModule, NzTableQueryParams } from 'ng-zorro-antd/table';
import { catchError, finalize, of, tap } from "rxjs";
import { JobModel } from "../../data-access/model/jobModel.model";
import { NzDividerModule } from 'ng-zorro-antd/divider';
import { NzButtonModule } from "ng-zorro-antd/button";
import { NzSpaceModule } from 'ng-zorro-antd/space';
import { NzModalModule, NzModalService } from 'ng-zorro-antd/modal';
import { FormBuilder, ReactiveFormsModule, Validators } from "@angular/forms";
import { NzFormModule } from "ng-zorro-antd/form";
import { NzSelectModule } from 'ng-zorro-antd/select';

//#endregion
//#region Component
@Component({
  selector: "meu-admin-job",
  templateUrl: "./Job.component.html",
  standalone: true,
  imports: [CommonModule,
    NzTableModule,
    NzDividerModule,
    NzButtonModule,
    NzSpaceModule,
    NzModalModule,
    NzModalModule,
    NzFormModule,
    ReactiveFormsModule,
    NzSelectModule
  ],
})
//#endregion
export class JobComponent implements OnInit {

  //#region Variable
  selectedJob?: JobModel;
  listOfJob: JobModel[] = [];
  loading = true;
  message = "";
  //modal
  isOpenModal = false;
  isOnEdit = false;
  isOnAdd = false;
  validateJobForm = this.fb.group({
    type: this.fb.control('', [Validators.required]),
    create_at: this.fb.control('', [Validators.required]),
    company_url: this.fb.control('', [Validators.required]),
    company: this.fb.control('', [Validators.required]),
    location: this.fb.control('', [Validators.required]),
    title: this.fb.control('', [Validators.required]),
    description: this.fb.control('', [Validators.required]),
  });
  //#endregion
  //#region LoadData
  constructor(private fb: FormBuilder, private jobService: JobService, private modal: NzModalService) { }
  loadDataFromServer(): void {
    console.log("hello");
    this.loading = true;
    this.jobService.jobsGet().pipe(
      tap((res) => {
        if (res.responseData)
          this.listOfJob = res.responseData.rows;
      }),
      catchError((err) => {
        this.listOfJob = [];
        return of(null);
      }),
      finalize(() => (this.loading = false))
    ).subscribe();
  }

  ngOnInit(): void {
    this.loadDataFromServer();
  }
  //#endregion


  //#region Handler
  resetForm() {
    this.validateJobForm.reset();
    this.selectedJob = {} as JobModel;
  }
  EnableForm() {
    this.validateJobForm.enable();
  }
  DisableForm() {
    this.validateJobForm.disable();
  }
  onOk(): void {
    console.log(this.onEdit, this.selectedJob);
    if (this.isOnEdit && this.selectedJob) {
      const updatedJob: JobModel = {
        id: this.selectedJob.id,
        type: this.validateJobForm.value.type ?? undefined,
        created_at: this.selectedJob.created_at,
        company: this.validateJobForm.value.company ?? undefined,
        company_url: this.validateJobForm.value.company_url ?? undefined,
        location: this.validateJobForm.value.location ?? undefined,
        title: this.validateJobForm.value.title ?? undefined,
        description: this.validateJobForm.value.description ?? undefined,

      };
      this.loading = true;
      this.jobService.editJob(updatedJob).pipe(
        tap((res) => {
          this.message = res.message;
          this.loadDataFromServer();
        }),
        catchError((err) => {
          console.error(err);
          return of(null);
        })
      ).subscribe();
    } else if (this.isOnAdd && this.selectedJob) {
      const newJob: JobModel = {
        id: this.selectedJob.id,
        type: this.validateJobForm.value.type ?? undefined,
        created_at: this.selectedJob.created_at,
        company: this.validateJobForm.value.company ?? undefined,
        company_url: this.validateJobForm.value.company_url ?? undefined,
        location: this.validateJobForm.value.location ?? undefined,
        title: this.validateJobForm.value.title ?? undefined,
        description: this.validateJobForm.value.description ?? undefined,
      };
      this.loading = true;
      this.jobService.addingNewJob(newJob).pipe(
        tap((res) => {
          this.message = res.message;
          this.loadDataFromServer();
        }),
        catchError((err) => {
          console.error(err);
          return of(null);
        })
      ).subscribe();
    }
    this.isOpenModal = false;
    this.isOnEdit = false;
    this.isOnAdd = false;
  }

  onCancel(): void {
    this.isOpenModal = false;
    this.isOnEdit = false;
  }
  //#endregion


  //#region Action
  JobDetail(id: string) {
    this.DisableForm();
    this.isOnEdit = false;
    this.isOpenModal = true;
    this.isOnAdd = false;
    this.jobService.getJob(id).pipe(
      tap((res) => {
        console.log(res);
        this.selectedJob = res.responseData as JobModel;
      }),
      catchError((err) => {
        console.log(err);
        return of(null);
      }),

      finalize(() => (
        this.loadDataFromServer(), this.loading = false))
    ).subscribe();
  }
  onDelete(id: string) {
    this.jobService.deleteJob(id).pipe(
      tap((res) => {
        this.loading = true;
        this.message = res.message;
      }),
      catchError((err) => {
        console.log(err);
        return of(null);
      }),
      finalize(() => (
        this.loadDataFromServer(),
        this.loading = false))
    ).subscribe();
  }
  onEdit(data: JobModel) {
    this.EnableForm();
    this.isOpenModal = true;
    this.isOnEdit = true;
    this.isOnAdd = false;
    this.selectedJob = data;
  }
  addJob() {
    this.EnableForm();
    this.resetForm();
    this.isOpenModal = true;
    this.isOnEdit = false;
    this.isOnAdd = true;
  }
  showDeleteConfirm(id: string): void {
    this.modal.confirm({
      nzTitle: 'Bạn có chắc rằng xóa công việc này không?',
      nzOkText: 'Xóa',
      nzOkType: 'primary',
      nzOkDanger: true,
      nzOnOk: () => this.onDelete(id),
      nzCancelText: 'trở về',
    });
  }
  //#endregion
}
