import { Injectable } from '@angular/core';
import { HttpClient, HttpHeaders, HttpParams, HttpRequest } from '@angular/common/http';
import { Observable } from 'rxjs';
import { environment } from '../../../../environments/environment.development';
import { JobModel } from '../model/jobModel.model';
import { ResponseResult, Rows } from '../../../shared/data-access/interface/response.type';


@Injectable({
  providedIn: 'root',
})
export class JobService {
  apiUrl = environment.API_DOMAIN + '/jobs';
  apiUrlById = environment.API_DOMAIN + '/jobById';
  constructor(private http: HttpClient) {}

  jobsGet(): Observable<ResponseResult<Rows<JobModel>>> {
    return this.http.get<ResponseResult<Rows<JobModel>>>(this.apiUrl);
  }

  addingNewJob(data: JobModel): Observable<ResponseResult<JobModel>> {
    const headers = new HttpHeaders()
      .set('Content-Type', 'application/json')
      .set('Authorization', `Bearer ${localStorage.getItem('token')}`);
    return this.http.post<ResponseResult<JobModel>>(this.apiUrl, data, { headers });
  }
  deleteJob(id: string): Observable<ResponseResult<JobModel>> {
    const headers = new HttpHeaders()
      .set('Content-Type', 'application/json')
      .set('Authorization', `Bearer ${localStorage.getItem('token')}`);
    const url = `${this.apiUrl}/${id}`;
    return this.http.delete<ResponseResult<JobModel>>(url, { headers });
  }
  editJob(data: JobModel): Observable<ResponseResult<JobModel>> {
    const headers = new HttpHeaders()
      .set('Content-Type', 'application/json')
      .set('Authorization', `Bearer ${localStorage.getItem('token')}`);
    const url = `${this.apiUrl}/${data.id}`;
    return this.http.put<ResponseResult<JobModel>>(url, data, { headers });
  }
  getJob(id: string): Observable<ResponseResult<JobModel>> {
    const headers = new HttpHeaders()
      .set('Content-Type', 'application/json')
      .set('Authorization', `Bearer ${localStorage.getItem('token')}`);
    const url = `${this.apiUrlById}/${id}`;
    console.log(id, url);
    return this.http.get<ResponseResult<JobModel>>(url, { headers });
  }

}
