import { ChangeDetectionStrategy, Component, OnInit } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { NzCardModule } from 'ng-zorro-antd/card';
import { NzInputModule } from 'ng-zorro-antd/input'
import { NzButtonModule } from 'ng-zorro-antd/button';
import { NzIconModule } from 'ng-zorro-antd/icon';
import { NzCheckboxModule } from 'ng-zorro-antd/checkbox';
import { NzFormModule } from 'ng-zorro-antd/form';
import { NzAlertModule } from 'ng-zorro-antd/alert';

import { CommonModule } from '@angular/common';
import { FormBuilder, FormGroup, FormsModule, ReactiveFormsModule, Validators } from '@angular/forms';
import { catchError, finalize, Observable, of, tap } from 'rxjs';
import { response } from 'express';
import { AuthService } from '../data-access/Services/Auth.Service';
import { userNameRegex } from '../../shared/data-access/const/user-name-regex.const';
@Component({
  selector: 'meu-login',
  standalone: true,
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss'],
  imports: [CommonModule,
    FormsModule,
    ReactiveFormsModule,
    NzFormModule,
    NzCardModule,
    NzInputModule,
    NzButtonModule,
    NzIconModule,
    NzCheckboxModule,
    NzAlertModule,
    NzFormModule,
    ReactiveFormsModule,
],
  changeDetection: ChangeDetectionStrategy.OnPush,
})
export class LoginComponent implements OnInit {
  MgsError: string = '';

  loginForm: FormGroup;
  constructor(private fb: FormBuilder, private authService: AuthService) {
    this.loginForm = this.fb.group({
      userName: ['', [Validators.required]],
      password: ['', [Validators.required]],
    });
  }
  ngOnInit() {}
  validateUserName(userName: string): boolean {
    const regex = new RegExp(userNameRegex);
    return regex.test(userName);
  }
  onSubmit() {
    if (!this.loginForm.valid) {
      this.MgsError = "Vui lòng nhập thông tin đăng nhập";
      return;
    }
    if (!this.validateUserName(this.loginForm.value.userName)) {
      this.MgsError = "tài khoản không được thêm các kí tự đặc biệt";
      return;
    }

    this.authService.login(this.loginForm.value.userName, this.loginForm.value.password).pipe(
      catchError((err) => {
        this.MgsError = err.message;
        console.log(this.MgsError);
        console.log(err);
        return of(null);
      }),
      finalize(() => {
        if(this.authService.isLoggedIn())
          this.authService.loginSussces();
        console.log('Login request completed');
      })
    ).subscribe();
  }
}
